@@ -1,9 +1,11 @@
 '''
-    OpenTAXII, Python TAXII server implementation from Intelworks.
+    OpenTAXII, TAXII server implementation from EclecticIQ.
 '''
 # flake8: noqa
 
 from ._version import __version__
-from .server import create_server
+from .server import TAXIIServer
 from .config import ServerConfig
 from .entities import Account
+
+from .local import context
