@@ -1,6 +1,9 @@
-from flask import Blueprint, request, jsonify, abort, current_app
+from flask import Blueprint, request, jsonify, abort
+
+from .local import context
+
+management = Blueprint('management', __name__)
 
-management = Blueprint('some', __name__)
 
 @management.route('/auth', methods=['POST'])
 def auth():
@@ -12,10 +15,14 @@ def auth():
     if not username or not password:
         return 'Both username and password are required', 400
 
-    token = current_app.taxii.auth.authenticate(username, password)
+    token = context.server.auth.authenticate(username, password)
 
     if not token:
         abort(401)
-    
-    return jsonify(token=token)
 
+    return jsonify(token=token.decode('utf-8'))
+
+
+@management.route('/health', methods=['GET'])
+def health():
+    return jsonify(alive=True)
